# required to suppress devtools::check() notes that occur from data.table syntax
utils::globalVariables(c(
  ".", "Datum", "Komponente", "Komponente_txt",
  "Lieferung", "Nachweisgrenze", "Station", "Uhrzeit", "Uhrzeit_num",
  "Wert", "Wert01", "Wert24", "day", "part", "prediction_upper",
  "prediction_lower", "prediction",
  "se", "time", "value", "variable", "WIR", "WIG", "year", "Werte_aggregiert"
))
